[llvm-commits] CVS: llvm/lib/Target/Sparc/Sparc.cpp SparcInternals.h

Brian Gaeke gaeke at cs.uiuc.edu
Thu Sep 18 12:38:14 PDT 2003


Changes in directory llvm/lib/Target/Sparc:

Sparc.cpp updated: 1.80 -> 1.81
SparcInternals.h updated: 1.100 -> 1.101

---
Log message:

Fix a typo in Sparc.cpp.
Update names of some pass creator fns in addPassesToEmitAssembly().
FunctionInfo is gone.


---
Diffs of the changes:

Index: llvm/lib/Target/Sparc/Sparc.cpp
diff -u llvm/lib/Target/Sparc/Sparc.cpp:1.80 llvm/lib/Target/Sparc/Sparc.cpp:1.81
--- llvm/lib/Target/Sparc/Sparc.cpp:1.80	Mon Sep  1 15:40:59 2003
+++ llvm/lib/Target/Sparc/Sparc.cpp	Thu Sep 18 12:37:46 2003
@@ -180,7 +180,7 @@
   
   // If LLVM dumping after transformations is requested, add it to the pipeline
   if (DumpInput)
-    PM.add(new PrintFunctionPass("Input code to instsr. selection:\n",
+    PM.add(new PrintFunctionPass("Input code to instr. selection:\n",
                                  &std::cerr));
 
   PM.add(createInstructionSelectionPass(*this));
@@ -196,7 +196,7 @@
     PM.add(createPeepholeOptsPass(*this));
 
   if (EmitMappingInfo)
-    PM.add(getMappingInfoCollector(Out));  
+    PM.add(getMappingInfoAsmPrinterPass(Out));  
 
   // Output assembly language to the .s file.  Assembly emission is split into
   // two parts: Function output and Global value output.  This is because
@@ -211,10 +211,8 @@
   PM.add(getModuleAsmPrinterPass(Out));
 
   // Emit bytecode to the assembly file into its special section next
-  if (EmitMappingInfo) {
-    PM.add(getEmitBytecodeToAsmPass(Out));
-    PM.add(getFunctionInfo(Out)); 
-  }
+  if (EmitMappingInfo)
+    PM.add(getBytecodeAsmPrinterPass(Out));
 
   return false;
 }


Index: llvm/lib/Target/Sparc/SparcInternals.h
diff -u llvm/lib/Target/Sparc/SparcInternals.h:1.100 llvm/lib/Target/Sparc/SparcInternals.h:1.101
--- llvm/lib/Target/Sparc/SparcInternals.h:1.100	Mon Sep  1 15:40:59 2003
+++ llvm/lib/Target/Sparc/SparcInternals.h	Thu Sep 18 12:37:46 2003
@@ -687,10 +687,8 @@
   // getModuleAsmPrinterPass - Writes generated machine code to assembly file.
   Pass* getModuleAsmPrinterPass(std::ostream &Out);
 
-  // getEmitBytecodeToAsmPass - Emits final LLVM bytecode to assembly file.
-  Pass* getEmitBytecodeToAsmPass(std::ostream &Out);
+  // getBytecodeAsmPrinterPass - Emits final LLVM bytecode to assembly file.
+  Pass* getBytecodeAsmPrinterPass(std::ostream &Out);
 };
-
-Pass *getFunctionInfo(std::ostream &out);
 
 #endif





More information about the llvm-commits mailing list